#
# spec file for package audiotube
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define kf6_version 6.6.0
%define qt6_version 6.6.0

%{?sle15_python_module_pythons}
%if 0%{?suse_version} == 1500
%define pyver python311
%else
# latest
%define pyver python3
%endif

%bcond_without released
Name:           audiotube
Version:        25.04.0
Release:        1.1
Summary:        YT Music player and playlists manager
License:        GPL-2.0-or-later
URL:            https://apps.kde.org/audiotube/
Source0:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz.sig
Source2:        applications.keyring
%endif
BuildRequires:  kf6-extra-cmake-modules >= %{kf6_version}
# Temporary: SR#1188363
BuildRequires:  %{pyver}-devel
BuildRequires:  %{pyver}-ytmusicapi
# ffmpeg and ffmpeg-mini-libs can be out of sync, leading to unresolvable conflicts
#!BuildIgnore: ffmpeg
BuildRequires:  %{pyver}-yt-dlp
BuildRequires:  cmake(FutureSQL6)
BuildRequires:  cmake(KF6CoreAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6Crash) >= %{kf6_version}
BuildRequires:  cmake(KF6I18n) >= %{kf6_version}
BuildRequires:  cmake(KF6Kirigami) >= %{kf6_version}
BuildRequires:  cmake(KF6KirigamiAddons) >= 0.11
BuildRequires:  cmake(KF6WindowSystem) >= %{kf6_version}
BuildRequires:  cmake(QCoro6Core) >= 0.10.0
BuildRequires:  cmake(Qt6Concurrent) >= %{qt6_version}
BuildRequires:  cmake(Qt6Core) >= %{qt6_version}
BuildRequires:  cmake(Qt6DBus) >= %{qt6_version}
BuildRequires:  cmake(Qt6Gui) >= %{qt6_version}
BuildRequires:  cmake(Qt6Multimedia) >= %{qt6_version}
BuildRequires:  cmake(Qt6Qml) >= %{qt6_version}
BuildRequires:  cmake(Qt6QuickControls2) >= %{qt6_version}
BuildRequires:  cmake(Qt6Sql) >= %{qt6_version}
BuildRequires:  cmake(Qt6Svg) >= %{qt6_version}
BuildRequires:  cmake(Qt6Widgets) >= %{qt6_version}
BuildRequires:  cmake(pybind11)
# audio/mpeg decoder is needed
Requires:       gstreamer-plugins-bad
Requires:       kf6-kirigami-imports >= %{kf6_version}
Requires:       kf6-purpose >= %{kf6_version}
Requires:       kirigami-addons6 >= 0.11
Requires:       %{pyver}-ytmusicapi
Requires:       qt6-declarative-imports >= %{qt6_version}
Requires:       qt6-multimedia-imports >= %{qt6_version}
Requires:       qt6-sql-sqlite >= %{qt6_version}
Requires:       yt-dlp

%description
AudioTube can search YouTube Music, list albums and artists, play automatically
generated playlists, albums and allows to put your own playlist together. It is
adapted to mobile phones and desktop computers.

%lang_package

%prep
%autosetup -p1

# The plugins CMake config files are intentionally removed from Qt6 packages,
# don't fail because of missing Qt6::QGstreamerMediaPlugin target
sed -i 's#FATAL_ERROR#STATUS#' CMakeLists.txt

%build
%cmake_kf6

%kf6_build

%install
%kf6_install

%find_lang %{name}

%files
%license LICENSES/*
%doc README.md
%{_kf6_applicationsdir}/org.kde.audiotube.desktop
%{_kf6_appstreamdir}/org.kde.audiotube.appdata.xml
%{_kf6_bindir}/audiotube
%{_kf6_iconsdir}/hicolor/scalable/apps/org.kde.audiotube.svg

%files lang -f %{name}.lang

%changelog
* Mon Apr 14 2025 Christophe Marin <christophe@krop.fr>
- Update to 25.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/25.04.0/
- No code change since 25.03.90
* Sat Mar 29 2025 Christophe Marin <christophe@krop.fr>
- Update to 25.03.90
  * New feature release
- Changes since 24.12.3:
  * Fix loading certain artist pages
  * cmake: Require ytmisicapi 1.10.2
  * Update to ytmusicapi 1.10.2
  * Fixes for the software renderer
  * Update tested ytmusicapi version to 1.10.1
  * Fix loading albums without id
  * Appdata: add display size
  * Fix skipping based on lyrics (skipping in general is still broken)
  * center lyrics horizontally
  * Update ytmusicapi to 1.9.0
  * LyricsModel: Fix error handling
  * MaximizedPlayerPage: solve some unqualified accesses
  * Unify lyrics font size
  * Add synchronized lyrics
  * Removed empty line just in case
  * Added Alessio Adamo as supporter
  * Add the album name to MaximizedPlayerPage
  * flatpak: Update dependencies
  * Fix appdata to align with appstream spec
  * Fix parsing certain playlists
  * flatpak: Update runtime to 6.8
* Tue Mar  4 2025 Christophe Marin <christophe@krop.fr>
- Update to 24.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.3/
- Changes since 24.12.2:
  * Update tested ytmusicapi version to 1.10.1
  * Update ytmusicapi to 1.9.0
  * Fix loading albums without id
  * Appdata: add display size
* Tue Feb  4 2025 Christophe Marin <christophe@krop.fr>
- Update to 24.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.2/
- No code change since 24.12.1
* Tue Jan  7 2025 Christophe Marin <christophe@krop.fr>
- Update to 24.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.1/
- No code change since 24.12.0
* Sun Dec  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.0/
- No code change since 24.11.90
* Mon Dec  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.11.90
  * New feature release
- No code change since 24.11.80
* Sat Nov 16 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.11.80
  * New feature release
- Changes since 24.08.3:
  * Fix parsing certain playlists
  * snap: update for latest release
  * flatpak: Switch yt-dlp away from flatpak-builder-tools
  * Update ytmusicapi to 1.8.2
  * LibraryPage: Fix text colour
  * Use regular Qt.createComponent
  * About: Use Qt.createComponent to create About Page
  * Fix up 19a48e4c
  * Main: Store window geomety with KConfig.WindowStateSaver
  * appstream: Switch summary to sentence case
  * Update tested ytmusicapi version to 1.8.0
* Tue Nov  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.3/
- Changes since 24.08.2:
  * LibraryPage: Fix text colour
* Tue Oct  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.2/
- No code change since 24.08.1
* Tue Sep 10 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.1/
- No code change since 24.08.0
* Mon Aug 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.0/
- Changes since 24.05.2:
  * appstream: Switch summary to sentence case
  * Update tested ytmusicapi version to 1.8.0
  * Handle playlists without thumbnails
  * ListHeader: Fix item width on mobile
  * Fix adding a song to a playlist
  * ShareMenu: Fix layout on mobile
  * Error out if the gstreamer backend is not available
  * Document gstreamer requirement
  * Update ytmusicapi to 1.7.0
* Thu Jul 18 2024 Christophe Marin <christophe@krop.fr>
- Init audiotube
